@@ -5,15 +5,10 @@
 */
 
 #include "defaultcombinedviewformatter.h"
-#include "akregator_debug.h"
 #include "akregatorconfig.h"
 #include "article.h"
-#include "feed.h"
-#include "folder.h"
 #include "grantleeviewformatter.h"
 #include "treenode.h"
-#include "treenodevisitor.h"
-#include "utils.h"
 
 #include <QPaintDevice>
 #include <QString>
